==> owncloud-5.0.9.tgz: owncloud/apps/bookmarks/l10n/sl.php <==
<?php $TRANSLATIONS = array(
"No file provided for import" => "Ni navedene datoteke za uvoz",
"Unsupported file type for import" => "Vrsta datoteke ni podprta za uvoz",
"Bookmarks" => "Zaznamki",
"Tags" => "Oznake",
"Filter by tag" => "Razvrsti po značkah",
"Edit bookmark" => "Uredi zaznamke",
"Are you sure you want to remove this tag from every entry?" => "Ali res želite odstraniti te oznake iz vsakega vnosa?",
"Warning" => "Opozorilo",
"Import error" => "Napaka med uvozom",
"Import completed successfully." => "Uvoz je uspešno zaključen.",
"Uploading..." => "Nalagam ...",
"Bookm." => "Zaznam.",
"Add a bookmark" => "Dodaj zaznamek",
"Close" => "Zapri",
"The title of the page" => "Naziv strani",
"The address of the page" => "Naslov strani",
"Description of the page" => "Opis strani",
"Save" => "Shrani",
"Delete" => "Izbriši",
"Edit" => "Uredi",
"Cancel" => "Prekliči",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Povlecite gumb med svoje zaznamke in kliknite nanj, ko želite obiskano spletno stran hitro dodati med svoje zaznamke:",
"Read later" => "Preberi kasneje",
"Address" => "Naslov",
"Add" => "Dodaj",
"Related Tags" => "Sorodne oznake",
"Settings" => "Nastavitve",
"You have no bookmarks" => "Nimate zaznamkov",
"You can also try to import a bookmark file" => "Prav tako lahko poskusite uvoziti datoteko z zaznamki",
"Bookmarklet" => "Vstavek za zaznamke",
"Export & Import" => "Izvoz & uvoz",
"Export" => "Izvozi",
"Import" => "Uvozi"
);

==> owncloud-6.0.1.tgz: owncloud/apps/bookmarks/l10n/sl.php <==
<?php $TRANSLATIONS = array(
"No file provided for import" => "Ni navedene datoteke za uvoz",
"Unsupported file type for import" => "Vrsta datoteke ni podprta za uvoz",
"Bookmarks" => "Zaznamki",
"Tags" => "Oznake",
"Filter by tag" => "Razvrsti po oznakah",
"Edit bookmark" => "Uredi zaznamke",
"Are you sure you want to remove this tag from every entry?" => "Ali res želite odstraniti te oznake iz vsakega vnosa?",
"Warning" => "Opozorilo",
"Import error" => "Napaka med uvozom",
"Import completed successfully." => "Uvoz je uspešno zaključen.",
"Uploading..." => "Poteka pošiljanje ...",
"Bookm." => "Zaznam.",
"Add a bookmark" => "Dodaj zaznamek",
"Close" => "Zapri",
"The title of the page" => "Naziv strani",
"The address of the page" => "Naslov strani",
"Description of the page" => "Opis strani",
"Save" => "Shrani",
"Delete" => "Izbriši",
"Edit" => "Uredi",
"Cancel" => "Prekliči",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Povlecite gumb med zaznamke in kliknite nanj, kadar želite obiskano spletno stran hitro dodati med svoje zaznamke:",
"Add to ownCloud" => "Dodaj v oblak ownCloud",
"Address" => "Naslov",
"Add" => "Dodaj",
"Related Tags" => "Sorodne oznake",
"Settings" => "Nastavitve",
"You have no bookmarks" => "Ni shranjenih zaznamkov",
"You can also try to import a bookmark file" => "Prav tako je mogoče uvoziti datoteko z zaznamki",
"Bookmarklet" => "Vstavek za zaznamke",
"Export & Import" => "Izvoz in uvoz",
"Export" => "Izvozi",
"Import" => "Uvozi"
);
